Bandpass
========

.. currentmodule:: wwt_data_formats.enums

.. autoclass:: Bandpass
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Bandpass.GAMMA
      ~Bandpass.HYDROGEN_ALPHA
      ~Bandpass.INFRARED
      ~Bandpass.MICROWAVE
      ~Bandpass.RADIO
      ~Bandpass.ULTRAVIOLET
      ~Bandpass.VISIBLE
      ~Bandpass.VISIBLE_NIGHT
      ~Bandpass.XRAY

   .. rubric:: Attributes Documentation

   .. autoattribute:: GAMMA
   .. autoattribute:: HYDROGEN_ALPHA
   .. autoattribute:: INFRARED
   .. autoattribute:: MICROWAVE
   .. autoattribute:: RADIO
   .. autoattribute:: ULTRAVIOLET
   .. autoattribute:: VISIBLE
   .. autoattribute:: VISIBLE_NIGHT
   .. autoattribute:: XRAY
